@@ -1,4 +1,4 @@
 import bftool
 
 if __name__ == "__main__":
-    bftool.Runner().main()
+    bftool.Runner().run()
